@@ -1,5 +1,4 @@
 static pe_ring NQueue;
-static pe_ring Prepare, Check, AsyncCheck;
 static int StarvePrio = PE_QUEUES - 2;
 
 static void boot_queue()
@@ -7,9 +6,6 @@ static void boot_queue()
   int xx;
   HV *stash = gv_stashpv("Event", 1);
   PE_RING_INIT(&NQueue, 0);
-  PE_RING_INIT(&Prepare, 0);
-  PE_RING_INIT(&Check, 0);
-  PE_RING_INIT(&AsyncCheck, 0);
   newCONSTSUB(stash, "QUEUES", newSViv(PE_QUEUES));
   newCONSTSUB(stash, "PRIO_NORMAL", newSViv(PE_PRIO_NORMAL));
   newCONSTSUB(stash, "PRIO_HIGH", newSViv(PE_PRIO_HIGH));
@@ -81,86 +77,6 @@ static void queueEvent(pe_event *ev)
   }
 }
 
-static pe_qcallback *
-pe_add_hook(char *which, int is_perl, void *cb, void *ext_data)
-{
-  pe_qcallback *qcb;
-  New(PE_NEWID, qcb, 1, pe_qcallback);
-  PE_RING_INIT(&qcb->ring, qcb);
-  qcb->is_perl = is_perl;
-  if (is_perl) {
-    qcb->callback = SvREFCNT_inc((SV*)cb);
-    qcb->ext_data = 0;
-  }
-  else {
-    qcb->callback = cb;
-    qcb->ext_data = ext_data;
-  }
-  if (strEQ(which, "prepare"))
-    PE_RING_UNSHIFT(&qcb->ring, &Prepare);
-  else if (strEQ(which, "check"))
-    PE_RING_UNSHIFT(&qcb->ring, &Check);
-  else if (strEQ(which, "asynccheck"))
-    PE_RING_UNSHIFT(&qcb->ring, &AsyncCheck);
-  else
-    croak("Unknown hook '%s' in pe_add_hook", which);
-  return qcb;
-}
-
-static pe_qcallback *capi_add_hook(char *which, void *cb, void *ext_data)
-{ return pe_add_hook(which, 0, cb, ext_data); }
-
-static void pe_cancel_hook(pe_qcallback *qcb)
-{
-  if (qcb->is_perl)
-    SvREFCNT_dec((SV*)qcb->callback);
-  PE_RING_DETACH(&qcb->ring);
-  safefree(qcb);
-}
-
-static double pe_map_prepare(double tm)
-{
-  pe_qcallback *qcb = Prepare.prev->self;
-  while (qcb) {
-    if (qcb->is_perl) {
-      SV *got;
-      double when;
-      dSP;
-      PUSHMARK(SP);
-      PUTBACK;
-      perl_call_sv((SV*)qcb->callback, G_SCALAR);
-      SPAGAIN;
-      got = POPs;
-      PUTBACK;
-      when = SvNOK(got) ? SvNVX(got) : SvNV(got);
-      if (when < tm) tm = when;
-    }
-    else { /* !is_perl */
-      double got = (* (double(*)(void*)) qcb->callback)(qcb->ext_data);
-      if (got < tm) tm = got;
-    }
-    qcb = qcb->ring.prev->self;
-  }
-  return tm;
-}
-
-static void pe_map_check(pe_ring *List)
-{
-  pe_qcallback *qcb = List->prev->self;
-  while (qcb) {
-    if (qcb->is_perl) {
-      dSP;
-      PUSHMARK(SP);
-      PUTBACK;
-      perl_call_sv((SV*)qcb->callback, G_DISCARD);
-    }
-    else { /* !is_perl */
-      (* (void(*)(void*)) qcb->callback)(qcb->ext_data);
-    }
-    qcb = qcb->ring.prev->self;
-  }
-}
-
 /* The caller is responsible for SAVETMPS/FREETMPS! */
 static int pe_empty_queue(maxprio)
 {
@@ -190,6 +106,32 @@ static int pe_empty_queue(maxprio)
   }
 }
 
+static double pe_map_prepare(double tm)
+{
+  pe_qcallback *qcb = Prepare.prev->self;
+  while (qcb) {
+    if (qcb->is_perl) {
+      SV *got;
+      double when;
+      dSP;
+      PUSHMARK(SP);
+      PUTBACK;
+      perl_call_sv((SV*)qcb->callback, G_SCALAR);
+      SPAGAIN;
+      got = POPs;
+      PUTBACK;
+      when = SvNOK(got) ? SvNVX(got) : SvNV(got);
+      if (when < tm) tm = when;
+    }
+    else { /* !is_perl */
+      double got = (* (double(*)(void*)) qcb->callback)(qcb->ext_data);
+      if (got < tm) tm = got;
+    }
+    qcb = qcb->ring.prev->self;
+  }
+  return tm;
+}
+
 static void pe_queue_pending()
 {
   double tm = 0;
